Documentation
¶
Overview ¶
-- References for writing this library The original documentation that started it all: https://github.com/pbsds/hatena-server/wiki/PPM-format Used for testing to parse the first frame's first layer with a white paper and a black pen: https://gist.github.com/jaames/aa77713839c1dc948eefd445442bf606 Python parser to help shape the code: https://github.com/jaames/flipnote-tools/blob/master/scripts/dsi/ppmTools/ppmTools/ppmParser.py#L190 JavaScript parser to help shape the code: https://github.com/jaames/flipnote.js/blob/master/src/decoder/index.js#L304
Index ¶
Constants ¶
This section is empty.
Variables ¶
var (
Debug = false
)
Functions ¶
This section is empty.
Types ¶
type OpenConfig ¶
type OpenConfig struct {
SkipAnimationSize bool
SkipAuthorName bool
SkipAudioData bool
SkipAudioSize bool
SkipDate bool
SkipFileName bool
SkipFileNameCheck bool
SkipFrameCount bool
SkipFrameData bool
SkipFrames bool
SkipLastEditedAuthorID bool
SkipLastEditedAuthorIDCheck bool
SkipLastEditedAuthorName bool
SkipLockStatus bool
SkipMagicCheck bool
SkipOriginalAuthorID bool
SkipOriginalAuthorIDCheck bool
SkipOriginalAuthorName bool
SkipOriginalFileName bool
SkipOriginalFileNameCheck bool
SkipPartialFileName bool
SkipPreviewFrameN bool
SkipPreviousEditingAuthorID bool
SkipPreviousEditingAuthorIDCheck bool
SkipThumbnail bool
}
type PPM ¶
type PPM struct {
AuthorName string
Date int64
FileName string
FrameData FrameData
LastEditedAuthorID string
LastEditedAuthorName string
Locked bool
OriginalAuthorID string
OriginalAuthorName string
OriginalFileName string
PartialFileName string
PreviousEditingAuthorID string
SoundData SoundData
// Extra things
Success bool
FileLocation string
OpenConfig *OpenConfig
ThumbnailPalette []color.RGBA
}
Click to show internal directories.
Click to hide internal directories.